@@ -40,7 +40,7 @@ use constant {
     MAX_WEBSOCKET_SIZE         => 262_144,
 };
 
-our $VERSION = "v0.0.35";
+our $VERSION = "v0.0.36";
 
 has _listener_observables => sub { +{} };
 
@@ -593,7 +593,7 @@ sub register ($self, $app, $config) {
             my @old_states = map $_->{state}, $streams->@{@$stream_names};
             @old_states = map { (dclone [$_])->[0] } @old_states;
 
-            my @ret = $sub->(@old_states);
+            my @ret = $sub->(map $_->{state}, $streams->@{@$stream_names});
             @ret = await $ret[0] if $ret[0]->$_can('then');
             $is_array or @ret = ([@ret]);
 
